==> dhall-docs-1.0.11-114-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-docs
version:              1.0.11
visibility:           public
id:                   dhall-docs-1.0.11-Ep27maP2a1tIVj0hox5kIO
key:                  dhall-docs-1.0.11-Ep27maP2a1tIVj0hox5kIO
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  676011e4a51a4a8fb6fa0c7cc369fe65
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-docs-1.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-docs-1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.11-Ep27maP2a1tIVj0hox5kIO
depends:
    base-4.16.4.0 base16-bytestring-1.0.2.0-2zrcaj2dASWLOg7ed8DTQL
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptohash-sha256-0.11.102.1-371Jt5DwAMz5e6UHJQG3Qm
    dhall-1.41.2-FF1MAIfSxjSLs7q9DrLpFq directory-1.3.6.2
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    lens-family-core-2.1.3-1OBIJmYHsnQ2CJGGRserxu
    lucid-2.11.20230408-1PzgHHzFiZ74capWDFNt4i
    megaparsec-9.5.0-7z3AThgMzs3rnIZVIvVtE
    mmark-0.0.7.6-BYVwFkMIK6oJ4j8TG1p7v7 mtl-2.2.2
    optparse-applicative-0.17.1.0-Jx8WaQbsFK9BJBRr9ePa2T
    path-0.9.5-7AhO7w9Z1SoGC1kj5eELlC
    path-io-1.8.1-8dzO1zEUTHQ5V6rTFlTchw
    prettyprinter-1.7.1-1GpgcfSKvbVDLlexa0B7T5 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-docs-1.0.11-115-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-docs
version:              1.0.11
visibility:           public
id:                   dhall-docs-1.0.11-Ezf5Afa1kf36e4h2lbvz7f
key:                  dhall-docs-1.0.11-Ezf5Afa1kf36e4h2lbvz7f
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  63c4ddf79ec52a65fb589004e8c0b394
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-docs-1.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-docs-1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.11-Ezf5Afa1kf36e4h2lbvz7f
depends:
    base-4.16.4.0 base16-bytestring-1.0.2.0-A9wYMYPkQGuF1IeghmIXr6
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptohash-sha256-0.11.102.1-3jxEBB4ou9wJ3LY0WsnKkP
    dhall-1.41.2-8lcGzlWBobN2Px3gcZq6oO directory-1.3.6.2
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    lens-family-core-2.1.3-1OBIJmYHsnQ2CJGGRserxu
    lucid-2.11.20230408-I7HuuHqZOTy1FPg8pmykCO
    megaparsec-9.5.0-DxfwQCjqE2hCiHQSxnyUED
    mmark-0.0.7.6-SlJzAdZCg48FJZ7MvbRx0 mtl-2.2.2
    optparse-applicative-0.17.1.0-Jx8WaQbsFK9BJBRr9ePa2T
    path-0.9.5-89iHqj14869BLhb3V7RKZS
    path-io-1.8.1-8lh5kk3Eirc1yCo9WFH5Ij
    prettyprinter-1.7.1-EpDMPqmBYmR4MhKdVLm3Ed text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
